package game.monstersandwizards;

import static org.junit.Assert.*;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

import game.monstersandwizards.Monster;

/**
 * @author jcbach
 *
 */
public class MonsterTest {

	/**
	 * @throws java.lang.Exception
	 */
	static Monster livingBeast;
	static Monster deadBeast;
	static Monster target;
	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
		livingBeast = new Monster("The Beast", 42);
		deadBeast = new Monster("The (dead) Beast", 0);
		target = new Monster("Target monster", 10);
	}

	/**
	 * @throws java.lang.Exception
	 */
	@AfterClass
	public static void tearDownAfterClass() throws Exception {
	}

	/**
	 * @throws java.lang.Exception
	 */
	@Before
	public void setUp() throws Exception {
		livingBeast.setLife(42);
		deadBeast.setLife(0);
		target.setLife(10);
	}

	/**
	 * @throws java.lang.Exception
	 */
	@After
	public void tearDown() throws Exception {
	}

	/**
	 * Test method for {@link game.monstersandwizards.Monster#attack(game.monstersandwizards.Victim)}.
	 */
	@Test
	public void testAttackWhenAlive() {
		//1. target should be alive
		assertFalse(target.isDead());
		//2. check hit points of both attacker and target
		int beforeTarget = target.getLife();
		//should be 10, therefore:
		assertEquals(10,beforeTarget);
		int beforeAttacker = livingBeast.getLife();
		//should be 42, therefore:
		assertEquals(42,beforeAttacker);
		//3. the attacker... attacks
		livingBeast.attack(livingBeast);
		//4. check hit points of both attacker and target: they should have been
		//decreased
		int afterTarget = target.getLife();
		assertTrue(afterTarget<=beforeTarget);
		int afterAttacker = livingBeast.getLife();
		assertTrue(afterAttacker<=beforeAttacker);
	}

	/**
	 * Test method for {@link game.monstersandwizards.Monster#beingHit(int)}.
	 */
	@Test
	public void testBeingHit() {
		int beforeHit = target.getLife();
		int hit=5;
		int counterAttack = target.beingHit(hit);
		int afterHit = target.getLife();
		assertTrue(beforeHit>afterHit);
		assertTrue(counterAttack<hit);
	}
	

	/**
	 * Test method for {@link game.monstersandwizards.Monster#beingBewitched(int)}.
	 */
	@Test
	public void testBeingBewitched() {
		//uncomment the following test in order to provoke a failure
		//fail("Not yet implemented");
		//TODO: similar to test behingHit
		/*int beforeHit = target.getLife();
		int hit=5;
		int counterAttack = target.beingBewitched(hit);
		int afterHit = target.getLife();
		assertTrue(beforeHit>afterHit);
		assertTrue(counterAttack<hit);*/
	}

}
