package game.monstersandwizards;

import static org.junit.Assert.*;

import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

import game.monstersandwizards.Person;
import game.monstersandwizards.Monster;

public class PersonTest {
	static Person livingPerson;
	static Person deadPerson;
	static Person veryDeadPerson;
	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
		livingPerson = new Monster("ALivingPerson", 42);
		deadPerson = new Monster("ADeadPerson", 0);
		veryDeadPerson = new Monster("AVeryDeadPerson", -42);
	}

	@Before
	public void setUp() throws Exception {
		livingPerson.setLife(42);
		deadPerson.setLife(0);
		veryDeadPerson.setLife(-42);
	}

	@Test
	public void testGetName() {
		assertEquals(livingPerson.getName(),"ALivingPerson");
		assertEquals(deadPerson.getName(),"ADeadPerson");
		assertEquals(veryDeadPerson.getName(),"AVeryDeadPerson");
	}

	@Test
	public void testGetLife() {
		assertTrue(livingPerson.getLife()==42);
		assertTrue(deadPerson.getLife()==0);
		assertTrue(veryDeadPerson.getLife()==-42);
	}

	@Test
	public void testIsDead() {
		assertTrue(deadPerson.isDead());
		assertTrue(veryDeadPerson.isDead());
		assertFalse(livingPerson.isDead());
	}

	@Test
	public void testAddLifeHit() {
		int before = livingPerson.getLife();
		int hit=-10;
		livingPerson.addLife(hit);
		int after = livingPerson.getLife();
		assertTrue(before>after);
		assertTrue(after==(hit+before));
	}
	@Test
	public void testAddLifeHeal() {
		int before = livingPerson.getLife();
		int hit=10;
		livingPerson.addLife(hit);
		int after = livingPerson.getLife();
		assertTrue(before<after);
		assertTrue(after==(hit+before));
	}
	@Test
	public void testAddLifeNeutral() {
		int before = livingPerson.getLife();
		int hit=0;
		livingPerson.addLife(hit);
		int after = livingPerson.getLife();
		assertTrue(before==after);
		assertTrue(after==(hit+before));
	}

	@Test
	public void deathByAddLife() {
		int hit = -42;
		assertFalse(livingPerson.isDead());
		livingPerson.addLife(hit);
		assertEquals(livingPerson.getLife(),0);
		assertTrue(livingPerson.isDead());
	}
	
	@Test
	public void testExist() {
		assertTrue(livingPerson.exist());
		assertFalse(deadPerson.exist());
	}

	@Test
	public void testSetLife() {
		livingPerson.setLife(10);
		assertTrue(livingPerson.getLife()==10);
	}

}
